@@ -40,7 +40,7 @@ sub configure {
 
 	my @opts;
 	if (-e $this->get_buildpath("Android.bp")) {
-		push @opts, "Android.bp";
+		push @opts, "-o";
 		push @opts, "soong.mk";
 	}
 	$this->doit_in_builddir("mini-soong", @opts, @_);
